@@ -2,6 +2,7 @@ package integration
 
 import (
 	"bytes"
+	"context"
 	"fmt"
 	"io"
 	"io/ioutil"
@@ -22,6 +23,7 @@ import (
 	"github.com/elazarl/goproxy"
 	docker "github.com/fsouza/go-dockerclient"
 
+	kappsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/apitesting"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -382,6 +384,49 @@ func TestNewAppRunAll(t *testing.T) {
 				RouteClient:     okRouteClient.RouteV1(),
 				OriginNamespace: "default",
 			},
+			expected: map[string][]string{
+				"imageStream": {"ruby-hello-world", "ruby"},
+				"buildConfig": {"ruby-hello-world"},
+				"deployment":  {"ruby-hello-world"},
+				"service":     {"ruby-hello-world"},
+			},
+			expectedName:    "ruby-hello-world",
+			expectedVolumes: nil,
+			expectedErr:     nil,
+		},
+		{
+			name: "successful ruby app generation - deployment config",
+			config: &cmd.AppConfig{
+				ComponentInputs: cmd.ComponentInputs{
+					SourceRepositories: []string{"https://github.com/openshift/ruby-hello-world"},
+				},
+				Resolvers: cmd.Resolvers{
+					ImageStreamByAnnotationSearcher: app.NewImageStreamByAnnotationSearcher(okImageClient.ImageV1(), okImageClient.ImageV1(), []string{"default"}),
+					TemplateSearcher: app.TemplateSearcher{
+						Client:     okTemplateClient.TemplateV1(),
+						Namespaces: []string{"openshift", "default"},
+					},
+					DockerSearcher: fakeDockerSearcher(),
+					ImageStreamSearcher: app.ImageStreamSearcher{
+						Client:     okImageClient.ImageV1(),
+						Namespaces: []string{"default"},
+					},
+					Detector: app.SourceRepositoryEnumerator{
+						Detectors:         source.DefaultDetectors,
+						DockerfileTester:  dockerfile.NewTester(),
+						JenkinsfileTester: jenkinsfile.NewTester(),
+					},
+				},
+				GenerationInputs: cmd.GenerationInputs{
+					Strategy:         newapp.StrategySource,
+					DeploymentConfig: true,
+				},
+				Typer:           customScheme,
+				ImageClient:     okImageClient.ImageV1(),
+				TemplateClient:  okTemplateClient.TemplateV1(),
+				RouteClient:     okRouteClient.RouteV1(),
+				OriginNamespace: "default",
+			},
 			expected: map[string][]string{
 				"imageStream":      {"ruby-hello-world", "ruby"},
 				"buildConfig":      {"ruby-hello-world"},
@@ -428,10 +473,10 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"ruby-hello-world", "ruby"},
-				"buildConfig":      {"ruby-hello-world"},
-				"deploymentConfig": {"ruby-hello-world"},
-				"service":          {"ruby-hello-world"},
+				"imageStream": {"ruby-hello-world", "ruby"},
+				"buildConfig": {"ruby-hello-world"},
+				"deployment":  {"ruby-hello-world"},
+				"service":     {"ruby-hello-world"},
 			},
 			expectedName:    "ruby-hello-world",
 			expectedVolumes: nil,
@@ -472,10 +517,10 @@ func TestNewAppRunAll(t *testing.T) {
 			},
 			checkPort: "8080",
 			expected: map[string][]string{
-				"imageStream":      {"ruby-hello-world", "ruby-25-centos7"},
-				"buildConfig":      {"ruby-hello-world"},
-				"deploymentConfig": {"ruby-hello-world"},
-				"service":          {"ruby-hello-world"},
+				"imageStream": {"ruby-hello-world", "ruby-25-centos7"},
+				"buildConfig": {"ruby-hello-world"},
+				"deployment":  {"ruby-hello-world"},
+				"service":     {"ruby-hello-world"},
 			},
 			expectedName: "ruby-hello-world",
 			expectedErr:  nil,
@@ -512,10 +557,10 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"sti-ruby"},
-				"buildConfig":      {"sti-ruby"},
-				"deploymentConfig": {"sti-ruby"},
-				"service":          {"sti-ruby"},
+				"imageStream": {"sti-ruby"},
+				"buildConfig": {"sti-ruby"},
+				"deployment":  {"sti-ruby"},
+				"service":     {"sti-ruby"},
 			},
 			expectedName:    "sti-ruby",
 			expectedVolumes: nil,
@@ -553,10 +598,10 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"sti-ruby"},
-				"buildConfig":      {"sti-ruby"},
-				"deploymentConfig": {"sti-ruby"},
-				"service":          {"sti-ruby"},
+				"imageStream": {"sti-ruby"},
+				"buildConfig": {"sti-ruby"},
+				"deployment":  {"sti-ruby"},
+				"service":     {"sti-ruby"},
 			},
 			expectedName:    "sti-ruby",
 			expectedVolumes: nil,
@@ -607,10 +652,10 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"example", "ruby-hello-world"},
-				"buildConfig":      {"ruby-hello-world"},
-				"deploymentConfig": {"ruby-hello-world"},
-				"service":          {"ruby-hello-world"},
+				"imageStream": {"example", "ruby-hello-world"},
+				"buildConfig": {"ruby-hello-world"},
+				"deployment":  {"ruby-hello-world"},
+				"service":     {"ruby-hello-world"},
 			},
 			expectedName:    "ruby-hello-world",
 			expectedErr:     nil,
@@ -649,10 +694,10 @@ func TestNewAppRunAll(t *testing.T) {
 			},
 
 			expected: map[string][]string{
-				"imageStream":      {"mysql"},
-				"deploymentConfig": {"mysql"},
-				"service":          {"mysql"},
-				"volumeMounts":     {"mysql-volume-1"},
+				"imageStream":  {"mysql"},
+				"deployment":   {"mysql"},
+				"service":      {"mysql"},
+				"volumeMounts": {"mysql-volume-1"},
 			},
 			expectedName: "mysql",
 			expectedVolumes: map[string]string{
@@ -698,10 +743,10 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"ruby-hello-world", "ruby-25-centos7"},
-				"buildConfig":      {"ruby-hello-world"},
-				"deploymentConfig": {"ruby-hello-world"},
-				"service":          {"ruby-hello-world"},
+				"imageStream": {"ruby-hello-world", "ruby-25-centos7"},
+				"buildConfig": {"ruby-hello-world"},
+				"deployment":  {"ruby-hello-world"},
+				"service":     {"ruby-hello-world"},
 			},
 			expectedName: "ruby-hello-world",
 			expectedErr:  nil,
@@ -743,10 +788,10 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"ruby-hello-world"},
-				"buildConfig":      {"ruby-hello-world"},
-				"deploymentConfig": {"ruby-hello-world"},
-				"service":          {"ruby-hello-world"},
+				"imageStream": {"ruby-hello-world"},
+				"buildConfig": {"ruby-hello-world"},
+				"deployment":  {"ruby-hello-world"},
+				"service":     {"ruby-hello-world"},
 			},
 			expectedName: "ruby-hello-world",
 			expectedErr:  nil,
@@ -790,9 +835,9 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"custom"},
-				"deploymentConfig": {"custom"},
-				"service":          {"custom"},
+				"imageStream": {"custom"},
+				"deployment":  {"custom"},
+				"service":     {"custom"},
 			},
 			expectedName: "custom",
 			expectedErr:  nil,
@@ -826,9 +871,9 @@ func TestNewAppRunAll(t *testing.T) {
 				OriginNamespace: "default",
 			},
 			expected: map[string][]string{
-				"imageStream":      {"custom"},
-				"deploymentConfig": {"custom"},
-				"service":          {"custom"},
+				"imageStream": {"custom"},
+				"deployment":  {"custom"},
+				"service":     {"custom"},
 			},
 			expectedName: "custom",
 			errFn: func(err error) bool {
@@ -899,6 +944,27 @@ func TestNewAppRunAll(t *testing.T) {
 				case *imagev1.ImageStream:
 					got["imageStream"] = append(got["imageStream"], tp.Name)
 					imageStreams = append(imageStreams, tp)
+				case *kappsv1.Deployment:
+					got["deployment"] = append(got["deployment"], tp.Name)
+					podTemplate := tp.Spec.Template
+					for _, volume := range podTemplate.Spec.Volumes {
+						if volume.VolumeSource.EmptyDir != nil {
+							gotVolumes[volume.Name] = "EmptyDir"
+						} else {
+							gotVolumes[volume.Name] = "UNKNOWN"
+						}
+					}
+					for _, container := range podTemplate.Spec.Containers {
+						for _, volumeMount := range container.VolumeMounts {
+							got["volumeMounts"] = append(got["volumeMounts"], volumeMount.Name)
+						}
+					}
+					if test.config.Labels != nil {
+						if !mapContains(test.config.Labels, tp.Spec.Template.Labels) {
+							t.Errorf("%s: did not get expected deployment r selector. Expected: %v. Got: %v",
+								test.name, test.config.Labels, tp.Spec.Selector)
+						}
+					}
 				case *appsv1.DeploymentConfig:
 					got["deploymentConfig"] = append(got["deploymentConfig"], tp.Name)
 					if podTemplate := tp.Spec.Template; podTemplate != nil {
@@ -2009,7 +2075,6 @@ func TestNewAppListAndSearch(t *testing.T) {
 	for _, test := range tests {
 		stdout, stderr := PrepareAppConfig(test.options.Config)
 		test.options.Action.Out, test.options.ErrOut = stdout, stderr
-		test.options.BaseName = "oc"
 		test.options.CommandName = "new-app"
 
 		err := test.options.RunNewApp()
@@ -2380,8 +2445,8 @@ type NewAppFakeImageStreams struct {
 	proxy imagev1typedclient.ImageStreamInterface
 }
 
-func (c *NewAppFakeImageStreams) Get(name string, options metav1.GetOptions) (result *imagev1.ImageStream, err error) {
-	result, err = c.proxy.Get(name, options)
+func (c *NewAppFakeImageStreams) Get(ctx context.Context, name string, options metav1.GetOptions) (result *imagev1.ImageStream, err error) {
+	result, err = c.proxy.Get(ctx, name, options)
 	if err != nil {
 		return nil, err
 	}
@@ -2394,42 +2459,42 @@ func (c *NewAppFakeImageStreams) Get(name string, options metav1.GetOptions) (re
 	return result, nil
 }
 
-func (c *NewAppFakeImageStreams) List(opts metav1.ListOptions) (result *imagev1.ImageStreamList, err error) {
-	return c.proxy.List(opts)
+func (c *NewAppFakeImageStreams) List(ctx context.Context, opts metav1.ListOptions) (result *imagev1.ImageStreamList, err error) {
+	return c.proxy.List(ctx, opts)
 }
 
-func (c *NewAppFakeImageStreams) Watch(opts metav1.ListOptions) (kwatch.Interface, error) {
-	return c.proxy.Watch(opts)
+func (c *NewAppFakeImageStreams) Watch(ctx context.Context, opts metav1.ListOptions) (kwatch.Interface, error) {
+	return c.proxy.Watch(ctx, opts)
 }
 
-func (c *NewAppFakeImageStreams) Create(imageStream *imagev1.ImageStream) (result *imagev1.ImageStream, err error) {
-	return c.proxy.Create(imageStream)
+func (c *NewAppFakeImageStreams) Create(ctx context.Context, imageStream *imagev1.ImageStream, opts metav1.CreateOptions) (result *imagev1.ImageStream, err error) {
+	return c.proxy.Create(ctx, imageStream, opts)
 }
 
-func (c *NewAppFakeImageStreams) Update(imageStream *imagev1.ImageStream) (result *imagev1.ImageStream, err error) {
-	return c.proxy.Update(imageStream)
+func (c *NewAppFakeImageStreams) Update(ctx context.Context, imageStream *imagev1.ImageStream, opts metav1.UpdateOptions) (result *imagev1.ImageStream, err error) {
+	return c.proxy.Update(ctx, imageStream, opts)
 }
 
-func (c *NewAppFakeImageStreams) UpdateStatus(imageStream *imagev1.ImageStream) (*imagev1.ImageStream, error) {
-	return c.proxy.UpdateStatus(imageStream)
+func (c *NewAppFakeImageStreams) UpdateStatus(ctx context.Context, imageStream *imagev1.ImageStream, opts metav1.UpdateOptions) (*imagev1.ImageStream, error) {
+	return c.proxy.UpdateStatus(ctx, imageStream, opts)
 }
 
-func (c *NewAppFakeImageStreams) Delete(name string, options *metav1.DeleteOptions) error {
-	return c.proxy.Delete(name, options)
+func (c *NewAppFakeImageStreams) Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error {
+	return c.proxy.Delete(ctx, name, opts)
 }
 
-func (c *NewAppFakeImageStreams) DeleteCollection(options *metav1.DeleteOptions, listOptions metav1.ListOptions) error {
-	return c.proxy.DeleteCollection(options, listOptions)
+func (c *NewAppFakeImageStreams) DeleteCollection(ctx context.Context, options metav1.DeleteOptions, listOptions metav1.ListOptions) error {
+	return c.proxy.DeleteCollection(ctx, options, listOptions)
 }
 
-func (c *NewAppFakeImageStreams) Patch(name string, pt ktypes.PatchType, data []byte, subresources ...string) (result *imagev1.ImageStream, err error) {
-	return c.proxy.Patch(name, pt, data, subresources...)
+func (c *NewAppFakeImageStreams) Patch(ctx context.Context, name string, pt ktypes.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *imagev1.ImageStream, err error) {
+	return c.proxy.Patch(ctx, name, pt, data, opts, subresources...)
 }
 
-func (c *NewAppFakeImageStreams) Secrets(imageStreamName string, opts metav1.GetOptions) (result *corev1.SecretList, err error) {
-	return c.proxy.Secrets(imageStreamName, opts)
+func (c *NewAppFakeImageStreams) Secrets(ctx context.Context, imageStreamName string, opts metav1.GetOptions) (result *corev1.SecretList, err error) {
+	return c.proxy.Secrets(ctx, imageStreamName, opts)
 }
 
-func (c *NewAppFakeImageStreams) Layers(imageStreamName string, opts metav1.GetOptions) (result *imagev1.ImageStreamLayers, err error) {
-	return c.proxy.Layers(imageStreamName, opts)
+func (c *NewAppFakeImageStreams) Layers(ctx context.Context, imageStreamName string, opts metav1.GetOptions) (result *imagev1.ImageStreamLayers, err error) {
+	return c.proxy.Layers(ctx, imageStreamName, opts)
 }
